@@ -1,7 +1,7 @@
-`plot.ftsm` <- function(x,components,h,xlab1=x$y$xname,ylab1="Basis function",xlab2="Time",ylab2="Coefficient",
+`plot.ftsm` <- function(x,components,xlab1=x$y$xname,ylab1="Basis function",xlab2="Time",ylab2="Coefficient",
     mean.lab="Mean",level.lab="Level",main.title="Main effects",interaction.title="Interaction",
     basiscol=1, coeffcol=1, 
-    outlier.col=2, outlier.pch=19, outlier.cex=0.5, ...)
+    outlier.col=2, outlier.pch=19, outlier.cex=0.5, h, ...)
 {
     oldpar <- par(no.readonly=TRUE)
     mean <- is.element("mean",colnames(x$basis))
